/*
 * Copyright 2000, International Business Machines Corporation and others.
 * All Rights Reserved.
 * 
 * This software has been released under the terms of the IBM Public
 * License.  For details, see the LICENSE file in the top-level source
 * directory or online at http://www.openafs.org/dl/license10.html
 */

#define IDS_ERROR_LOADING_ICON			0
#define IDS_CPA_TITLE					1
#define IDS_EXECUTION_ERROR				2
#define IDS_APP_NAME					3

#define IDI_AFSD                        103
